@@ -29,12 +29,27 @@ class BaseHandler:
             self.entry = gopherentry.GopherEntry(self.selector, self.config)
         return self.entry
 
+    def getrootpath(self):
+        """Gets the root path."""
+        return self.config.get("pygopherd", "root")
+
     def getfspath(self):
         """Gets the filesystem path corresponding to the selector."""
         if self.fspath:
             return self.fspath
 
-        self.fspath = self.config.get("serving", "root") + \
-                      self.selector
+        self.fspath = self.getrootpath() + self.selector
 
         return self.fspath
+
+    def prepare(self):
+        """Prepares for a write.  Ie, opens a file.  This is
+        used so that the protocols can try to detect an error before
+        transmitting a result."""
+        pass
+
+    def write(self, wfile):
+        """Writes out the request.  Should be overridden.
+        Must always be called before write."""
+        pass
+
