@@ -5,7 +5,7 @@ import handlers, handlers.base
 
 class DirHandler(handlers.base.BaseHandler):
     def canhandlerequest(self):
-        """We can handle the request if it's for a file."""
+        """We can handle the request if it's for a directory."""
         return os.path.isdir(self.getfspath())
 
     def getentry(self):
@@ -14,10 +14,11 @@ class DirHandler(handlers.base.BaseHandler):
             self.entry.populatefromfs(self.getfspath())
         return self.entry
 
-    def write(self, wfile):
-        files = os.listdir(self.getfspath())
-        files.sort()
+    def prepare(self):
+        self.files = os.listdir(self.getfspath())
+        self.files.sort()
 
+    def write(self, wfile):
         selectorbase = self.selector
         if selectorbase == '/':
             selectorbase = ''           # Avoid dup slashes
@@ -25,7 +26,13 @@ class DirHandler(handlers.base.BaseHandler):
         if fsbase == '/':
             fsbase = ''                 # Avoid dup slashes
 
-        for file in files:
+        ignorepatt = self.config.get("handlers.dir.DirHandler", "ignorepatt")
+
+        for file in self.files:
+            # Skip files we're ignoring.
+            if re.search(ignorepatt, selectorbase + '/' + file):
+                continue
+            
             fileentry = gopherentry.GopherEntry(selectorbase + '/' + file,
                                           self.config)
             fileentry.populatefromfs(fsbase + '/' + file)
