@@ -1,6 +1,6 @@
 import SocketServer
 import re
-import os, stat, os.path, mimetypes, handlers, protocols
+import os, stat, os.path, mimetypes, handlers, protocols, protocols.rfc1436
 
 class EnhancedGopherProtocol(protocols.rfc1436.GopherProtocol):
     def renderobjinfo(self, entry):
